Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(113)

Unified Diff: pkg/compiler/lib/src/js_backend/js_interop_analysis.dart

Issue 2625713002: Rename Enqueuer.universe to worldBuilder. (Closed)
Patch Set: Updated cf. comments Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/compiler/lib/src/js_backend/enqueuer.dart ('k') | pkg/compiler/lib/src/js_backend/namer.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/compiler/lib/src/js_backend/js_interop_analysis.dart
diff --git a/pkg/compiler/lib/src/js_backend/js_interop_analysis.dart b/pkg/compiler/lib/src/js_backend/js_interop_analysis.dart
index a89326b1d689608cdd0a6393e801f9f52b773851..b2ad759f7454b2b20e583d7c16aec3f6d9e7af15 100644
--- a/pkg/compiler/lib/src/js_backend/js_interop_analysis.dart
+++ b/pkg/compiler/lib/src/js_backend/js_interop_analysis.dart
@@ -117,7 +117,10 @@ class JsInteropAnalysis {
// Skip classes that are completely unreachable. This should only happen
// when all of jsinterop types are unreachable from main.
- if (!backend.compiler.resolverWorld.isImplemented(classElement)) return;
+ if (!backend.compiler.resolutionWorldBuilder
+ .isImplemented(classElement)) {
+ return;
+ }
if (!classElement.implementsInterface(helpers.jsJavaScriptObjectClass)) {
backend.reporter.reportErrorMessage(classElement,
@@ -166,7 +169,7 @@ class JsInteropAnalysis {
jsAst.Statement buildJsInteropBootstrap() {
if (!enabledJsInterop) return null;
List<jsAst.Statement> statements = <jsAst.Statement>[];
- backend.compiler.codegenWorld.forEachInvokedName(
+ backend.compiler.codegenWorldBuilder.forEachInvokedName(
(String name, Map<Selector, SelectorConstraints> selectors) {
selectors.forEach((Selector selector, SelectorConstraints constraints) {
if (selector.isClosureCall) {
@@ -189,7 +192,7 @@ class JsInteropAnalysis {
}
ResolutionFunctionType buildJsFunctionType() {
// TODO(jacobr): consider using codegenWorld.isChecks to determine the
// range of positional arguments that need to be supported by JavaScript
// function types.
return new ResolutionFunctionType.synthesized(
@@ -189,7 +192,7 @@ class JsInteropAnalysis {
}
ResolutionFunctionType buildJsFunctionType() {
- // TODO(jacobr): consider using codegenWorld.isChecks to determine the
+ // TODO(jacobr): consider using codegenWorldBuilder.isChecks to determine the
// range of positional arguments that need to be supported by JavaScript
// function types.
« no previous file with comments | « pkg/compiler/lib/src/js_backend/enqueuer.dart ('k') | pkg/compiler/lib/src/js_backend/namer.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698